function [Props,AsgnVals] = pnames(sys)
%PNAMES  All public properties and their assignable values
%
%   [PROPS,ASGNVALS] = PNAMES(SYS)  returns the list PROPS of
%   public properties of the object SYS (a cell vector), as well as 
%   the assignable values ASGNVALS for these properties (a cell vector
%   of strings).  PROPS contains the true case-sensitive property names.
%   These include the public properties of SYS's parent(s).
%
%   See also  GET, SET.

%       Author(s): P. Gahinet, 7-8-97
%       Copyright 1986-2002 The MathWorks, Inc. 
%       $Revision: 1.12 $  $Date: 2002/04/10 05:48:52 $


% LTI properties
Props = {'Ts'; 'ioDelay' ; 'InputDelay'; 'OutputDelay'; ...
      'InputName' ; 'OutputName' ; 'InputGroup' ; 'OutputGroup' ; ...
      'Notes' ; 'UserData'};
   
% Also return assignable values if needed
if nargout>1,
   AsgnVals = {'Scalar (sample time in seconds)'; ...
               'Ny-by-Nu array (I/O delays)';...
               'Nu-by-1 vector';...
               'Ny-by-1 vector'; ...
               'Nu-by-1 cell array of strings'; ...
               'Ny-by-1 cell array of strings'; ...
               'M-by-2 cell array for M input groups'; ...
               'P-by-2 cell array for P output groups'; ...
               'Array or cell array of strings'; ...
               'Arbitrary'};
end

