function GridOptions = gridopts(GridType)
%GRIDOPTS  Returns template for specifying grid options.
%
%    OPTSTRUCT = GRIDOPTS(GRIDTYPE) where GRIDTYPE can be one of
%    the following: 'pzmap', 'nichols', or 'nyquist'.

%   Author(s): P. Gahinet
%   Copyright 1986-2002 The MathWorks, Inc. 
%   $Revision: 1.3 $  $Date: 2002/04/10 04:43:57 $

switch GridType
case 'pzmap'
   % Pole/zero grids
   GridOptions = struct(...
      'Damping',NaN,...
      'Frequency',NaN,...
      'FrequencyUnits','rad/sec',...
      'GridLabelType','damping',...
      'SampleTime',-1,...
      'LimInclude','off',...
      'Zlevel',0);
   
case 'nichols'
   % Nichols chart
   GridOptions = struct(...
      'PhaseUnits','deg',...
      'LimInclude','off',...
      'Zlevel',0);
   
case 'nyquist'
   % Nyquist grid
   GridOptions = struct(...
      'FrequencyUnits','rad/sec',...
      'MagnitudeUnits','dB',...
      'Zlevel',0);
   
end